from setuptools import setup

setup(
    name='mvsearch',
    version='1.0',
    description='The Head First Python Search Tools',
    author='majie',
    author_email='1206765895@qq.com',
    py_modules=['vsearch'],
)